#ifndef TIMELINE_H
#define TIMELINE_H

#include <QDockWidget>
#include <QPushButton>
#include <QScrollArea>
#include <QGraphicsView>
#include <QGraphicsScene>
#include <QGraphicsRectItem>
#include <QList>

#include "keyframegraphicsitem.h"
#include "framespangraphicsitem.h"
#include "clickablegraphicsview.h"


class TimeLine : public QDockWidget
{
    Q_OBJECT
public:
    void Init();
    explicit TimeLine(const QString & title, QWidget * parent = 0, Qt::WindowFlags flags = 0) :
        QDockWidget(title, parent, flags) {Init();};
    explicit TimeLine(QWidget * parent = 0, Qt::WindowFlags flags = 0) :
        QDockWidget(parent, flags) {Init();} ;


    // components
    QPushButton* addObjectButton;
    QScrollArea* scrollArea;

    ClickableGraphicsView* headerView;
    QGraphicsScene* headerScene;

    ClickableGraphicsView* mainView;
    QGraphicsScene* mainScene;

    QGraphicsRectItem* headerFrameMarker;
    QGraphicsRectItem* mainFrameMarker;

    // drawing stuff
    int columnWidth;
    int rowHeight;

    QList<QMetaObject::Connection> objectConnections;

    QList<KeyFrameGraphicsItem*> keyFrameItems;
    QList<FrameSpanGraphicsItem*> frameSpanItems;

public slots:
    void reload();
    void reloadList();
    void reloadMarkers();

    void addObject();


    void connectToState();
    void filterStateChange(int f);

    void connectToObjects();
    void filterObjectsChange(int f);

    void viewClicked(QPoint pos);
    int scrollPosToFrame(int pos);

};

#endif // TIMELINE_H
