#ifndef DATASTATE_H
#define DATASTATE_H

#include <QObject>
#include <QList>
#include <QSignalMapper>

#include "../Models/videocontainer.h"
#include "../Models/trackedobject.h"

class DataState : public QObject
{
    Q_OBJECT
public:
    enum ChangeFlags {
        CurrentObjectChange = 1<<0,
        CurrentFrameChange = 1<<1,
        ObjectsListChange = 1<<2
    };

    explicit DataState(QObject *parent = 0);



    ~DataState();

    //define << operator
    friend QDataStream& operator<<(QDataStream& out, const DataState &outPut){
        out<<outPut.dataStateVersion;
        out<<outPut.currentFrame;
        out<<outPut.objectsList.size();
        for (int i = 0; i < outPut.objectsList.size(); i++){
            out<<*(outPut.objectsList.at(i));
        }
        out<<TrackedObject::newID;
        return out;
    }
    //define >> operator
    friend QDataStream& operator>>(QDataStream& in, DataState &inPut){
        in>>inPut.dataStateVersion;
        in>>inPut.currentFrame;
        int size=0;
        in>>size;
        for (int i = 0; i < size; i++){
            inPut.addObject();
            in>>*(inPut.objectsList.at(i));
        }
        in>>TrackedObject::newID;
        return in;
    }


    QString dataStateVersion;
    bool videoLoaded;
    VideoContainer* vid;

    int currentFrame;

    QList<TrackedObject*> objectsList;
    int currentObjectID;

    bool hasObjects();

    QList<QColor> colors;




public slots:
    void setFrame(int f);
    void nextFrame();
    void prevFrame();

    void addObject();
    TrackedObject * getCurrentObject();
    void setCurrentObject(int id);

    TrackedObject * getObjectById(int id);

    void deleteObject(int id);

    QList<TrackedObject*> getZOrderSortedList(int frame);



signals:
    void hasChanged(int flags);

};

#endif // DATASTATE_H
